#[repr(C)]pub struct Config {
pub character_width: CharacterWidth,
pub stop_width: StopWidth,
pub parity: Parity,
pub control_flow: FlowControl,
pub baud_rate: u32,
}Fields
character_width: CharacterWidthstop_width: StopWidthparity: Paritycontrol_flow: FlowControlbaud_rate: u32Trait Implementations
impl Copy for Config
Sourceimpl<___E> Encode<Config, ___E> for Configwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Config, ___E> for Configwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, Config>
const COPY_OPTIMIZATION: CopyOptimization<Self, Config>
Sourceimpl<'a, ___E> Encode<Config, ___E> for &'a Configwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Config, ___E> for &'a Configwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> EncodeOption<Box<'static, Config>, ___E> for Config
impl<___E> EncodeOption<Box<'static, Config>, ___E> for Config
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Config>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Config>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Config>, ___E> for &'a Config
impl<'a, ___E> EncodeOption<Box<'static, Config>, ___E> for &'a Config
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Config>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Config>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for Config
Sourceimpl FromWireRef<Config> for Config
impl FromWireRef<Config> for Config
Sourcefn from_wire_ref(wire: &Config) -> Self
fn from_wire_ref(wire: &Config) -> Self
Converts the given reference to this type.
Sourceimpl Ord for Config
impl Ord for Config
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for Config
impl PartialOrd for Config
impl StructuralPartialEq for Config