#[repr(C)]pub struct DeviceGetClassResponse {
pub device_class: Class,
}Fields
device_class: ClassTrait Implementations
Sourceimpl Clone for DeviceGetClassResponse
impl Clone for DeviceGetClassResponse
Sourcefn clone(&self) -> DeviceGetClassResponse
fn clone(&self) -> DeviceGetClassResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DeviceGetClassResponse
Sourceimpl Debug for DeviceGetClassResponse
impl Debug for DeviceGetClassResponse
Sourceimpl<___E> Encode<DeviceGetClassResponse, ___E> for DeviceGetClassResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetClassResponse, ___E> for DeviceGetClassResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetClassResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetClassResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetClassResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetClassResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<DeviceGetClassResponse, ___E> for &'a DeviceGetClassResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetClassResponse, ___E> for &'a DeviceGetClassResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetClassResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetClassResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetClassResponse>, ___E> for DeviceGetClassResponse
impl<___E> EncodeOption<Box<'static, DeviceGetClassResponse>, ___E> for DeviceGetClassResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetClassResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetClassResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceGetClassResponse>, ___E> for &'a DeviceGetClassResponse
impl<'a, ___E> EncodeOption<Box<'static, DeviceGetClassResponse>, ___E> for &'a DeviceGetClassResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetClassResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetClassResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for DeviceGetClassResponse
Sourceimpl FromWire<DeviceGetClassResponse> for DeviceGetClassResponse
impl FromWire<DeviceGetClassResponse> for DeviceGetClassResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetClassResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetClassResponse, Self>
Sourcefn from_wire(wire: DeviceGetClassResponse) -> Self
fn from_wire(wire: DeviceGetClassResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetClassResponse> for DeviceGetClassResponse
impl FromWireRef<DeviceGetClassResponse> for DeviceGetClassResponse
Sourcefn from_wire_ref(wire: &DeviceGetClassResponse) -> Self
fn from_wire_ref(wire: &DeviceGetClassResponse) -> Self
Converts the given reference to this type.
Sourceimpl Hash for DeviceGetClassResponse
impl Hash for DeviceGetClassResponse
Sourceimpl Ord for DeviceGetClassResponse
impl Ord for DeviceGetClassResponse
Sourcefn cmp(&self, other: &DeviceGetClassResponse) -> Ordering
fn cmp(&self, other: &DeviceGetClassResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for DeviceGetClassResponse
impl PartialEq for DeviceGetClassResponse
Sourceimpl PartialOrd for DeviceGetClassResponse
impl PartialOrd for DeviceGetClassResponse
impl StructuralPartialEq for DeviceGetClassResponse