#[repr(C)]pub struct DeviceSetConfigResponse {
pub s: Result<(), Status>,
}Fields
s: Result<(), Status>Trait Implementations
Sourceimpl Clone for DeviceSetConfigResponse
impl Clone for DeviceSetConfigResponse
Sourcefn clone(&self) -> DeviceSetConfigResponse
fn clone(&self) -> DeviceSetConfigResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DeviceSetConfigResponse
Sourceimpl Debug for DeviceSetConfigResponse
impl Debug for DeviceSetConfigResponse
Sourceimpl<___E> Encode<DeviceSetConfigResponse, ___E> for DeviceSetConfigResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceSetConfigResponse, ___E> for DeviceSetConfigResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceSetConfigResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceSetConfigResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceSetConfigResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceSetConfigResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<DeviceSetConfigResponse, ___E> for &'a DeviceSetConfigResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceSetConfigResponse, ___E> for &'a DeviceSetConfigResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceSetConfigResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceSetConfigResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, DeviceSetConfigResponse>, ___E> for DeviceSetConfigResponse
impl<___E> EncodeOption<Box<'static, DeviceSetConfigResponse>, ___E> for DeviceSetConfigResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceSetConfigResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceSetConfigResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceSetConfigResponse>, ___E> for &'a DeviceSetConfigResponse
impl<'a, ___E> EncodeOption<Box<'static, DeviceSetConfigResponse>, ___E> for &'a DeviceSetConfigResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceSetConfigResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceSetConfigResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for DeviceSetConfigResponse
Sourceimpl FromWire<DeviceSetConfigResponse> for DeviceSetConfigResponse
impl FromWire<DeviceSetConfigResponse> for DeviceSetConfigResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceSetConfigResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceSetConfigResponse, Self>
Sourcefn from_wire(wire: DeviceSetConfigResponse) -> Self
fn from_wire(wire: DeviceSetConfigResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceSetConfigResponse> for DeviceSetConfigResponse
impl FromWireRef<DeviceSetConfigResponse> for DeviceSetConfigResponse
Sourcefn from_wire_ref(wire: &DeviceSetConfigResponse) -> Self
fn from_wire_ref(wire: &DeviceSetConfigResponse) -> Self
Converts the given reference to this type.
Sourceimpl Hash for DeviceSetConfigResponse
impl Hash for DeviceSetConfigResponse
Sourceimpl Ord for DeviceSetConfigResponse
impl Ord for DeviceSetConfigResponse
Sourcefn cmp(&self, other: &DeviceSetConfigResponse) -> Ordering
fn cmp(&self, other: &DeviceSetConfigResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for DeviceSetConfigResponse
impl PartialEq for DeviceSetConfigResponse
Sourceimpl PartialOrd for DeviceSetConfigResponse
impl PartialOrd for DeviceSetConfigResponse
impl StructuralPartialEq for DeviceSetConfigResponse