#[repr(C)]pub struct DeviceGetClassResponse {
pub device_class: Class,
}Expand description
The wire type corresponding to DeviceGetClassResponse.
Fields
device_class: ClassTrait Implementations
Sourceimpl Clone for DeviceGetClassResponse
impl Clone for DeviceGetClassResponse
Sourcefn clone(&self) -> DeviceGetClassResponse
fn clone(&self) -> DeviceGetClassResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceGetClassResponse
impl Constrained for DeviceGetClassResponse
Sourceimpl Debug for DeviceGetClassResponse
impl Debug for DeviceGetClassResponse
Sourceimpl<___D> Decode<___D> for DeviceGetClassResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceGetClassResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<DeviceGetClassResponse, ___E> for DeviceGetClassResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetClassResponse, ___E> for DeviceGetClassResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetClassResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetClassResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetClassResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetClassResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<DeviceGetClassResponse, ___E> for &'a DeviceGetClassResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetClassResponse, ___E> for &'a DeviceGetClassResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetClassResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetClassResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<DeviceGetClassResponse, ___E> for DeviceGetClassResponse<T0>
impl<___E, T0> Encode<DeviceGetClassResponse, ___E> for DeviceGetClassResponse<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetClassResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetClassResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetClassResponse> for DeviceGetClassResponse
impl FromWire<DeviceGetClassResponse> for DeviceGetClassResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetClassResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetClassResponse, Self>
Sourcefn from_wire(wire: DeviceGetClassResponse) -> Self
fn from_wire(wire: DeviceGetClassResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetClassResponse> for DeviceGetClassResponse
impl FromWireRef<DeviceGetClassResponse> for DeviceGetClassResponse
Sourcefn from_wire_ref(wire: &DeviceGetClassResponse) -> Self
fn from_wire_ref(wire: &DeviceGetClassResponse) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceGetClassResponse
impl IntoNatural for DeviceGetClassResponse
Sourcetype Natural = DeviceGetClassResponse
type Natural = DeviceGetClassResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetClassResponse
impl Wire for DeviceGetClassResponse
Sourcetype Narrowed<'de> = DeviceGetClassResponse
type Narrowed<'de> = DeviceGetClassResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.