#[repr(C)]pub struct DeviceSetConfigResponse {
pub s: StatusResult,
}Expand description
The wire type corresponding to DeviceSetConfigResponse.
Fields
s: StatusResultTrait Implementations
Sourceimpl Clone for DeviceSetConfigResponse
impl Clone for DeviceSetConfigResponse
Sourcefn clone(&self) -> DeviceSetConfigResponse
fn clone(&self) -> DeviceSetConfigResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceSetConfigResponse
impl Constrained for DeviceSetConfigResponse
Sourceimpl Debug for DeviceSetConfigResponse
impl Debug for DeviceSetConfigResponse
Sourceimpl<___D> Decode<___D> for DeviceSetConfigResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceSetConfigResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<DeviceSetConfigResponse, ___E> for DeviceSetConfigResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceSetConfigResponse, ___E> for DeviceSetConfigResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceSetConfigResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceSetConfigResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceSetConfigResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceSetConfigResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<DeviceSetConfigResponse, ___E> for &'a DeviceSetConfigResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceSetConfigResponse, ___E> for &'a DeviceSetConfigResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceSetConfigResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceSetConfigResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<DeviceSetConfigResponse, ___E> for DeviceSetConfigResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StatusResult, ___E>,
impl<___E, T0> Encode<DeviceSetConfigResponse, ___E> for DeviceSetConfigResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StatusResult, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceSetConfigResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceSetConfigResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceSetConfigResponse> for DeviceSetConfigResponse
impl FromWire<DeviceSetConfigResponse> for DeviceSetConfigResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceSetConfigResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceSetConfigResponse, Self>
Sourcefn from_wire(wire: DeviceSetConfigResponse) -> Self
fn from_wire(wire: DeviceSetConfigResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceSetConfigResponse> for DeviceSetConfigResponse
impl FromWireRef<DeviceSetConfigResponse> for DeviceSetConfigResponse
Sourcefn from_wire_ref(wire: &DeviceSetConfigResponse) -> Self
fn from_wire_ref(wire: &DeviceSetConfigResponse) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceSetConfigResponse
impl IntoNatural for DeviceSetConfigResponse
Sourcetype Natural = DeviceSetConfigResponse
type Natural = DeviceSetConfigResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceSetConfigResponse
impl Wire for DeviceSetConfigResponse
Sourcetype Narrowed<'de> = DeviceSetConfigResponse
type Narrowed<'de> = DeviceSetConfigResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.